@@ -35,17 +35,14 @@ Functions to build mask files for PyDrizzle.
 import os
 
 from stsci.tools import fileutil, readgeis
-try:
-    from stsci.tools.bitmask import bitfield_to_boolean_mask
-except ImportError:
-    from stsci.tools.bitmask import bitmask2mask as bitfield_to_boolean_mask
+from stsci.tools.bitmask import bitfield_to_boolean_mask
 
 from astropy.io import fits
 import numpy as np
 
 from . import processInput, util
 
-__taskname__ = 'drizzlepac.buildmask'
+__taskname__ = 'buildmask'
 #
 #### Interactive interface
 #
@@ -81,7 +78,7 @@ def buildDQMasks(imageObjectList,configObj):
 
 def buildMask(dqarr, bitvalue):
     """ Builds a bit-mask from an input DQ array and a bitvalue flag """
-    return bitfield_to_boolean_mask(dqarr, bitvalue, good_mask_value=1,
+    return bitfield_to_boolean_mask(dqarr.astype(np.int16), bitvalue, good_mask_value=1,
                                     dtype=np.uint8)
 
 
