@@ -17,7 +17,6 @@ import sys
 from enum import Enum
 from astropy.io.fits import getheader
 from astropy.table import Table
-import numpy as np
 
 from stsci.tools import logutil
 
@@ -25,7 +24,7 @@ __taskname__ = 'analyze'
 
 MSG_DATEFMT = '%Y%j%H%M%S'
 SPLUNK_MSG_FORMAT = '%(asctime)s %(levelname)s src=%(name)s- %(message)s'
-log = logutil.create_logger(__name__, level=logutil.logging.DEBUG, stream=sys.stdout,
+log = logutil.create_logger(__name__, level=logutil.logging.INFO, stream=sys.stdout,
                             format=SPLUNK_MSG_FORMAT, datefmt=MSG_DATEFMT)
 
 __all__ = ['analyze_data', 'analyze_wrapper', 'mvm_analyze_wrapper']
@@ -44,6 +43,7 @@ FGSKEY = 'FGSLOCK'
 CHINKEY = 'CHINJECT'
 DRIZKEY = 'DRIZCORR'
 
+
 # Return codes 
 class Ret_code(Enum):
     """
@@ -53,6 +53,7 @@ class Ret_code(Enum):
     SBCHRC_DATA = 55 
     NO_VIABLE_DATA = 65
 
+
 # Annotates level to which image can be aligned according observational parameters
 # as described through FITS keywords
 class Messages(Enum):
@@ -471,3 +472,4 @@ def generate_msg(filename, msg, key, value):
         log.warning('Dataset cannot be aligned.')
     else:
         log.warning('Dataset can be aligned, but the result may be compromised.')
+
