@@ -12,12 +12,16 @@ from stsci.tools import logutil
 
 __taskname__ = 'astroquery_utils'
 
+product_type_dict = {'HAP': 'HAP', 'pipeline': 'DADS', 'both': ''}
+
 MSG_DATEFMT = '%Y%j%H%M%S'
 SPLUNK_MSG_FORMAT = '%(asctime)s %(levelname)s src=%(name)s- %(message)s'
 log = logutil.create_logger(__name__, level=logutil.logging.NOTSET, stream=sys.stdout, 
                             format=SPLUNK_MSG_FORMAT, datefmt=MSG_DATEFMT)
 
-def retrieve_observation(obsid, suffix=['FLC'], archive=False, clobber=False):
+
+def retrieve_observation(obsid, suffix=['FLC'], archive=False, clobber=False,
+                         product_type=None):
     """Simple interface for retrieving an observation from the MAST archive
 
     If the input obsid is for an association, it will request all members with
@@ -25,10 +29,12 @@ def retrieve_observation(obsid, suffix=['FLC'], archive=False, clobber=False):
 
     Parameters
     -----------
-    obsid : string
-        ID for observation to be retrieved from the MAST archive.  Only the
-        IPPSSOOT (rootname) of exposure or ASN needs to be provided; eg.,
-        ib6v06060.
+    obsid : string or list of strings
+        ID or list of IDs for observations to be retrieved from the MAST archive.
+        Only the IPPSSOOT (rootname) of exposure or ASN needs to be provided; eg.,
+        ib6v06060.  Additionally, a wild-carded `obsid` can be provided to
+        retrieve all products for a visit; e.g., "ib6v06*".  Data from multiple
+        ASNs, exposures or visits can be retrieved by simply providing them as a list.
 
     suffix : list, optional
         List containing suffixes of files which should be requested from MAST.
@@ -41,6 +47,17 @@ def retrieve_observation(obsid, suffix=['FLC'], archive=False, clobber=False):
     clobber : Boolean, optional
         Download and Overwrite existing files? Default is "False".
 
+    product_type : str, optional
+        Specify what type of product you want from the archive, either 'pipeline'
+        or 'HAP' or 'both' (default).  By default, all versions of the products
+        processed for the requested datasets will be returned.  This would include:
+          - pipeline : files processed by `runastrodriz` to include the latest
+                       distortion calibrations and the best possible alignment to GAIA
+                       with `ipppssoot_fl[tc].fits` filenames for FLT/FLC files.
+          - HAP : files processed as a single visit and aligned (as possible) to GAIA
+                  with `hst_<propid>_<visit>_<instr>_<det>_<filter>_<ipppssoo>_fl[tc].fits`
+                  filenames.
+
     Returns
     -------
     local_files : list
@@ -55,12 +72,17 @@ def retrieve_observation(obsid, suffix=['FLC'], archive=False, clobber=False):
     # Query MAST for the data with an observation type of either "science" or
     # "calibration"
     obs_table = Observations.query_criteria(obs_id=obsid)
+
     # Catch the case where no files are found for download
     if not obs_table:
         log.info("WARNING: Query for {} returned NO RESULTS!".format(obsid))
         return local_files
 
     dpobs = Observations.get_product_list(obs_table)
+    if product_type:
+        ptypes = [product_type_dict[product_type] in descr for descr in dpobs['description']]
+        dpobs = dpobs[ptypes]
+
     data_products_by_id = Observations.filter_products(dpobs,
                                                        productSubGroupDescription=suffix,
                                                        extension='fits',
