@@ -18,9 +18,6 @@ from . import util
 from .regfilter import fast_filter_outer_regions
 
 
-# This is specifically NOT intended to match the package-wide version information.
-__version__ = '0.1'
-__version_date__ = '11-Nov-2013'
 __taskname__ = 'mapreg'
 __author__ = 'Mihai Cara'
 
@@ -1084,55 +1081,7 @@ def run(configObj):
            verbose     = configObj['verbose'])
 
 
-def help(file=None):
-    """
-    Print out syntax help for running astrodrizzle
+MapReg.__doc__ = util._def_help_functions(
+    locals(), module_file=__file__, task_name=__taskname__, module_doc=__doc__
+)
 
-    Parameters
-    ----------
-    file : str (Default = None)
-        If given, write out help to the filename specified by this parameter
-        Any previously existing file with this name will be deleted before
-        writing out the help.
-
-    """
-    helpstr = getHelpAsString(docstring=True, show_ver = True)
-    if file is None:
-        print(helpstr)
-    else:
-        if os.path.exists(file): os.remove(file)
-        f = open(file, mode = 'w')
-        f.write(helpstr)
-        f.close()
-
-
-def getHelpAsString(docstring = False, show_ver = True):
-    """
-    return useful help from a file in the script directory called
-    __taskname__.help
-
-    """
-    install_dir = os.path.dirname(__file__)
-    taskname = util.base_taskname(__taskname__, '')
-    htmlfile = os.path.join(install_dir, 'htmlhelp', taskname + '.html')
-    helpfile = os.path.join(install_dir, taskname + '.help')
-
-    if docstring or (not docstring and not os.path.exists(htmlfile)):
-        if show_ver:
-            helpString = os.linesep + \
-                ' '.join([__taskname__, 'Version', __version__,
-                ' updated on ', __version_date__]) + 2*os.linesep
-        else:
-            helpString = ''
-        if os.path.exists(helpfile):
-            helpString += teal.getHelpFileAsString(taskname, __file__)
-        else:
-            if __doc__ is not None:
-                helpString += __doc__ + os.linesep
-    else:
-        helpString = 'file://' + htmlfile
-
-    return helpString
-
-
-MapReg.__doc__ = getHelpAsString(docstring = True, show_ver = False)
