@@ -33,11 +33,12 @@ import os
 import shutil
 import string
 import sys
+from packaging.version import Version
 
 import numpy as np
 import astropy
 from astropy.io import fits
-from astropy.nddata import interpret_bit_flags
+from stsci.tools.bitmask import interpret_bit_flags
 
 from stwcs import updatewcs as uw
 from stwcs.wcsutil import altwcs, wcscorr
@@ -260,8 +261,7 @@ def reportResourceUsage(imageObjectList, outwcs, num_cores,
         numchips += img._nmembers # account for group parameter set by user
 
     # if we have the cpus and s/w, ok, but still allow user to set pool size
-    pool_size = util.get_pool_size(num_cores, None)
-    pool_size = pool_size if (numchips >= pool_size) else numchips
+    pool_size = util.get_pool_size(num_cores, numchips)
 
     inimg = 0
     chip_mem = 0
@@ -600,10 +600,14 @@ def _process_input_wcs(infiles, wcskey, updatewcs):
     if pool_size > 1:
         log.info('Executing %d parallel workers' % pool_size)
         subprocs = []
+        mp_ctx = multiprocessing.get_context('fork')
+
         for fname in outfiles:
-            p = multiprocessing.Process(target=_process_input_wcs_single,
+            p = mp_ctx.Process(
+                target=_process_input_wcs_single,
                 name='processInput._process_input_wcs()', # for err msgs
-                args=(fname, wcskey, updatewcs) )
+                args=(fname, wcskey, updatewcs)
+            )
             subprocs.append(p)
         mputil.launch_and_wait(subprocs, pool_size) # blocks till all done
     else:
@@ -748,6 +752,11 @@ def changeSuffixinASN(asnfile, suffix):
     Create a copy of the original asn file and change the name of all members
     to include the suffix.
     """
+    if Version(astropy.__version__) >= Version('5.0.0'):
+        asn_decode = False
+    else:
+        asn_decode = True
+
     # Start by creating a new name for the ASN table
     _new_asn = asnfile.replace('_asn.fits','_'+suffix+'_asn.fits')
     if os.path.exists(_new_asn):
@@ -759,10 +768,17 @@ def changeSuffixinASN(asnfile, suffix):
     fasn = fits.open(_new_asn, mode='update', memmap=False)
     fasn[0].header['DUPCHECK'] = "COMPLETE"
     newdata = fasn[1].data.tolist()
+
     for i in range(len(newdata)):
-        val = newdata[i][0].decode(encoding='UTF-8').strip()
-        if 'prod' not in newdata[i][1].decode(encoding='UTF-8').lower():
-            val += '_'+suffix
+        if asn_decode:
+            val = newdata[i][0].decode(encoding='UTF-8').strip()
+            if 'prod' not in newdata[i][1].decode(encoding='UTF-8').lower():
+                val += '_'+suffix
+        else:
+            val = newdata[i][0].strip()
+            if 'prod' not in newdata[i][1].lower():
+                val += '_'+suffix
+
         newdata[i] = (val,newdata[i][1].strip(),newdata[i][2])
 
     # Redefine dtype to support longer strings for MEMNAME
@@ -778,6 +794,10 @@ def changeSuffixinASN(asnfile, suffix):
     # Assign newly created, reformatted array to extension
     newasn = np.array(newdata,dtype=new_dtype)
     fasn[1].data = newasn
+    # Explicitly set the values of the boolean column to original values since they get
+    # lost when writing out as a FITS_Rec object using the FITS interface.
+    for row, dcol in zip(fasn[1].data, newdata):
+        row['MEMPRSNT'] = dcol[2]
     fasn.close()
 
     return _new_asn
