@@ -26,13 +26,10 @@ from stsci.skypac.utils import get_ext_list, ext2str
 from . import updatehdr
 from . import linearfit
 from . import util
+from . import __version__
 
 
-__taskname__ = 'tweakback' # unless someone comes up with anything better
-
-# This is specifically NOT intended to match the package-wide version information.
-__version__ = '0.4.1'
-__version_date__ = '13-July-2020'
+__taskname__ = 'tweakback'
 
 
 log = logutil.create_logger(__name__, level=logutil.logging.NOTSET)
@@ -132,8 +129,8 @@ def tweakback(drzfile, input=None,  origwcs = None,
     stwcs.wcsutil.altwcs: Alternate WCS implementation
 
     """
-    print("TweakBack Version {:s}({:s}) started at: {:s}\n"
-          .format(__version__,__version_date__,util._ptime()[0]))
+    print("TweakBack Version {:s} started at: {:s}\n"
+          .format(__version__, util._ptime()[0]))
 
     # Interpret input list/string into list of filename(s)
     fltfiles = parseinput.parseinput(input)[0]
@@ -161,6 +158,8 @@ def tweakback(drzfile, input=None,  origwcs = None,
     ### Step 1: Read in updated and original WCS solutions
     # determine keys for all alternate WCS solutions in drizzled image header
     wkeys = wcsutil.altwcs.wcskeys(drzfile, ext=sciext)
+    if len(wkeys) < 2:
+        raise ValueError(f"'{drzfile}' must contain at least two valid WCS: original and updated.")
     wnames = wcsutil.altwcs.wcsnames(drzfile, ext=sciext)
     if not util.is_blank(newname):
         final_name = newname
@@ -170,25 +169,30 @@ def tweakback(drzfile, input=None,  origwcs = None,
     # Read in HSTWCS objects for final,updated WCS and previous WCS from
     # from drizzled image header
     # The final solution also serves as reference WCS when using updatehdr
+
     if not util.is_blank(wcsname):
-        for k in wnames:
-            if wnames[k] == wcsname:
-                wcskey = k
+        for wkey, wname in wnames.items():
+            if wname == wcsname:
+                wcskey = wkey
                 break
+        else:
+            raise ValueError(f"WCS with name '{wcsname}' not found in '{drzfile}'")
     else:
         wcskey = wkeys[-1]
-    final_wcs = wcsutil.HSTWCS(drzfile, ext=sciext, wcskey=wkeys[-1])
+
+    final_wcs = wcsutil.HSTWCS(drzfile, ext=sciext, wcskey=wcskey)
 
     if not util.is_blank(origwcs):
-        for k in wnames:
-            if wnames[k] == origwcs:
-                orig_wcskey = k
-                orig_wcsname = origwcs
+        for wkey, wname in wnames.items():
+            if wname == origwcs:
+                orig_wcskey = wkey
                 break
+        else:
+            raise ValueError(f"WCS with name '{origwcs}' not found in '{drzfile}'")
     else:
-        orig_wcsname,orig_wcskey = determine_orig_wcsname(scihdr,wnames,wkeys)
+         _, orig_wcskey = determine_orig_wcsname(scihdr, wnames, wkeys)
 
-    orig_wcs = wcsutil.HSTWCS(drzfile,ext=sciext,wcskey=orig_wcskey)
+    orig_wcs = wcsutil.HSTWCS(drzfile, ext=sciext, wcskey=orig_wcskey)
 
     # read in RMS values reported for new solution
     crderr1kw = 'CRDER1'+wkeys[-1]
@@ -392,52 +396,6 @@ def determine_orig_wcsname(header, wnames, wkeys):
     return orig_wcsname,orig_key
 
 
-def help(file=None):
-    """
-    Print out syntax help for running astrodrizzle
-
-    Parameters
-    ----------
-    file : str (Default = None)
-        If given, write out help to the filename specified by this parameter
-        Any previously existing file with this name will be deleted before
-        writing out the help.
-
-    """
-    helpstr = getHelpAsString(docstring=True, show_ver = True)
-    if file is None:
-        print(helpstr)
-    else:
-        if os.path.exists(file): os.remove(file)
-        f = open(file, mode = 'w')
-        f.write(helpstr)
-        f.close()
-
-
-def getHelpAsString(docstring = False, show_ver = True):
-    """
-    return useful help from a file in the script directory called
-    __taskname__.help
-
-    """
-    install_dir = os.path.dirname(__file__)
-    taskname = util.base_taskname(__taskname__, '')
-    htmlfile = os.path.join(install_dir, 'htmlhelp', taskname + '.html')
-    helpfile = os.path.join(install_dir, taskname + '.help')
-
-    if docstring or (not docstring and not os.path.exists(htmlfile)):
-        if show_ver:
-            helpString = os.linesep + \
-                ' '.join([__taskname__, 'Version', __version__,
-                ' updated on ', __version_date__]) + 2*os.linesep
-        else:
-            helpString = ''
-        if os.path.exists(helpfile):
-            helpString += teal.getHelpFileAsString(taskname, __file__)
-        else:
-            if __doc__ is not None:
-                helpString += tweakback.__doc__ + os.linesep
-    else:
-        helpString = 'file://' + htmlfile
-
-    return helpString
+util._def_help_functions(
+    locals(), module_file=__file__, task_name=__taskname__, module_doc=__doc__
+)
