@@ -17,22 +17,19 @@ from stwcs import updatewcs
 
 from . import util
 
-# __version__ and __version_date__ are defined here, prior to the importing
-# of the modules below, so that those modules can use the values
-# from these variable definitions, allowing the values to be designated
+# __version__ is defined here, prior to the importing
+# of the modules below, so that those modules can use the value
+# from this variable definition, allowing the value to be designated
 # in one location only.
 #
-# This is specifically NOT intended to match the package-wide version information.
-__version__ = '1.4.7'
-__version_date__ = '18-April-2018'
 
 from . import tweakutils
 from . import imgclasses
-from . import catalogs
 from . import imagefindpars
 from . import refimagefindpars
+from . import __version__
 
-__taskname__ = 'tweakreg' # unless someone comes up with anything better
+__taskname__ = 'tweakreg'
 
 PSET_SECTION        = '_SOURCE FINDING PARS_'
 PSET_SECTION_REFIMG = '_REF IMAGE SOURCE FINDING PARS_'
@@ -96,8 +93,8 @@ def run(configobj):
     """ Primary Python interface for image registration code
         This task replaces 'tweakshifts'
     """
-    print('TweakReg Version %s(%s) started at: %s \n'%(
-                    __version__,__version_date__,util._ptime()[0]))
+    print('TweakReg Version %s started at: %s \n'%(
+                    __version__, util._ptime()[0]))
     util.print_pkg_versions()
 
     # make sure 'updatewcs' is set to False when running from GUI or if missing
@@ -688,7 +685,7 @@ def run(configobj):
 
 def _overlap_matrix(images):
     nimg = len(images)
-    m = np.zeros((nimg,nimg), dtype=np.float)
+    m = np.zeros((nimg,nimg), dtype=float)
     for i in range(nimg):
         for j in range(i+1,nimg):
             p = images[i].skyline.intersection(images[j].skyline)
@@ -750,7 +747,7 @@ def _max_overlap_image(refimage, images, expand_refcat, enforce_user_order):
         # revert to old tweakreg behavior
         return images.pop(0)
 
-    area = np.zeros(nimg, dtype=np.float)
+    area = np.zeros(nimg, dtype=float)
     for i in range(nimg):
         area[i] = np.fabs(
             refimage.skyline.intersection(images[i].skyline).area()
@@ -843,55 +840,6 @@ def TweakReg(files=None, editpars=False, configobj=None, imagefindcfg=None,
         run(configObj)
 
 
-def help(file=None):
-    """
-    Print out syntax help for running astrodrizzle
-
-    Parameters
-    ----------
-    file : str (Default = None)
-        If given, write out help to the filename specified by this parameter
-        Any previously existing file with this name will be deleted before
-        writing out the help.
-
-    """
-    helpstr = getHelpAsString(docstring=True, show_ver = True)
-    if file is None:
-        print(helpstr)
-    else:
-        if os.path.exists(file): os.remove(file)
-        f = open(file, mode = 'w')
-        f.write(helpstr)
-        f.close()
-
-
-def getHelpAsString(docstring = False, show_ver = True):
-    """
-    return useful help from a file in the script directory called
-    __taskname__.help
-
-    """
-    install_dir = os.path.dirname(__file__)
-    taskname = util.base_taskname(__taskname__, '')
-    htmlfile = os.path.join(install_dir, 'htmlhelp', taskname + '.html')
-    helpfile = os.path.join(install_dir, taskname + '.help')
-
-    if docstring or (not docstring and not os.path.exists(htmlfile)):
-        if show_ver:
-            helpString = os.linesep + \
-                ' '.join([__taskname__, 'Version', __version__,
-                ' updated on ', __version_date__]) + 2*os.linesep
-        else:
-            helpString = ''
-        if os.path.exists(helpfile):
-            helpString += teal.getHelpFileAsString(taskname, __file__)
-        else:
-            if __doc__ is not None:
-                helpString += __doc__ + os.linesep
-    else:
-        helpString = 'file://' + htmlfile
-
-    return helpString
-
-
-TweakReg.__doc__ = getHelpAsString(docstring = True, show_ver = False)
+TweakReg.__doc__ = util._def_help_functions(
+    locals(), module_file=__file__, task_name=__taskname__, module_doc=__doc__
+)
