@@ -1,6 +1,7 @@
 """ This module is the high-level wrapper for running a test on a list of input
     datasets in order to collect statistics on alignment of each dataset to an
     astrometric catalog."""
+import sys
 import datetime
 import os
 import shutil
@@ -10,6 +11,11 @@ import pytest
 
 from drizzlepac import align as alignimages
 
+from stsci.tools import logutil
+
+log = logutil.create_logger('test_randomlist', level=logutil.logging.INFO, stream=sys.stdout)
+
+
 def pytest_generate_tests(metafunc):
     """Get the command line option."""
     start_row = metafunc.config.option.start_row
@@ -43,7 +49,7 @@ def pytest_generate_tests(metafunc):
 @pytest.mark.bigdata
 @pytest.mark.slow
 @pytest.mark.unit
-def test_randomlist(tmpdir, dataset):
+def test_randomlist(tmpdir, dataset, request):
     """ Tests which validate whether mosaics can be aligned to an astrometric standard.
 
         Characteristics of these tests:
@@ -110,31 +116,47 @@ def test_randomlist(tmpdir, dataset):
 
     try:
 
-        dataset_table = alignimages.perform_align([dataset], archive=False,
+        align_table = alignimages.perform_align([dataset],
+                                                  catalog_list=['GAIADR2', 'GAIADR1'],
+                                                  num_sources=250,
+                                                  archive=False,
                                                   clobber=True, debug=False,
                                                   update_hdr_wcs=False,
                                                   print_fit_parameters=True,
                                                   print_git_info=False,
-                                                  output=False)
+                                                  output=False,
+                                                  product_type='pipeline')
 
-        # Filtered datasets
-        if dataset_table['doProcess'].sum() == 0:
-            pytest.skip("TEST_RANDOM. Filtered Dataset: {}.".format(dataset))
-        # Datasets to process
-        elif dataset_table['doProcess'].sum() > 0:
-            # Determine images in dataset to be processed and the number of images
-            # This is in case an image was filtered out (e.g., expotime = 0)
-            index = np.where(dataset_table['doProcess'] == 1)[0]
-            fit_qual = dataset_table['fit_qual'][index[0]]
+        # The align_table could be None if there were not enough sources
+        # available for alignment.  This is not an error.
+        if align_table is None:
+            mark = pytest.mark.xfail(reason="TEST_RANDOM. There were not enough sources for processing for dataset.")
+            request.node.add_marker(mark)
+            assert 0
 
-            # Update the table with the dataset_key which is really just a counter
-            dataset_table['completed'][:] = True
-            dataset_table.write(output_name, format='ascii.ecsv')
+        else:
+            dataset_table = align_table.filtered_table
 
-            if fit_qual > 4:
-                pytest.fail("TEST_RANDOM. Unsuccessful Dataset (fit_qual = 5): {}.".format(dataset))
-            else:
-                assert 0 < fit_qual <= 4
+            # Filtered datasets
+            if dataset_table['doProcess'].sum() == 0:
+                pytest.skip("TEST_RANDOM. Filtered Dataset: {}.".format(dataset))
+            # Datasets to process
+            elif dataset_table['doProcess'].sum() > 0:
+                # Determine images in dataset to be processed and the number of images
+                # This is in case an image was filtered out (e.g., expotime = 0)
+                index = np.where(dataset_table['doProcess'] == 1)[0]
+                fit_qual = dataset_table['fit_qual'][index[0]]
+
+                # Update the table with the dataset_key which is really just a counter
+                dataset_table['completed'][:] = True
+                dataset_table.write(output_name, format='ascii.ecsv')
+
+                if fit_qual > 4:
+                    mark = pytest.mark.xfail(reason="TEST_RANDOM. Unsuccessful Dataset (fit_qual = 5).")
+                    request.node.add_marker(mark)
+                    assert 0
+                else:
+                    assert 0 < fit_qual <= 4
 
     # Catch anything that happens as this dataset will be considered a failure, but
     # the processing of datasets should continue.  This is meant to catch
